@@ -164,7 +164,8 @@ def getTimeFormat(str):
 def hours(t): 
     try:  return t.days*24.0 + t.seconds/3600.0 #t is a datetime object
     except AttributeError: return datetime.timedelta(hours=t) #t is a number
-
+def show_clock(show=True):
+    return 'clock time={}'.format(datetime.datetime.now().strftime('%H:%M:%S')) if show else ''
 
 ####################### class stuff #######################
 def getattrL(L,attribute='name'):
@@ -180,6 +181,21 @@ def getclass_inlist(L,values,attribute='name'):
     if len(indL)==1: return L[indL[0]]
     else: return [L[ind] for ind in indL]
 
+def update_attributes(instance, variables, exclude=['self'],include=None):
+    """Update instance attributes
+ 
+    For example, update(self, locals())
+    
+    instance: Instance to update via setattr()
+    variables: Dictionary of variables
+    exclude: Variables to explicitly exclude, defaults to ['self'].
+    include: Variables to explicitly include. If set, include overides exclude.
+    """
+    if include is not None: [setattr(instance,k,v) for k,v in variables.items() if k in include]
+    else:
+        if 'self' not in exclude: exclude.append('self')
+        [setattr(instance, k, v) for k, v in variables.items() if k not in exclude]
+ 
 ####################### dict stuff ########################
 def subset(D, subsetL):
     '''subset of dictionary'''
@@ -190,4 +206,4 @@ def subset(D, subsetL):
 def subsetexcept(D,exceptL):
     '''dictionary without exceptions list'''
     for e in exceptL: D.pop(e)
-    return D
+    return D
\ No newline at end of file
