@@ -1,8 +1,9 @@
 """
-Get data from csv files and parse it into lists of power systems class instances
-(:class:`~powersystems.Generator`, :class:`~powersystems.Line`, and :class:`~powersystems.Load`). 
-Create lists of :class:`~powersystems.Bus` and :class:`~powersystems.Line` instances
-from the information found in the data.
+Get data from spreadsheet files and parse it into 
+:class:`~powersystems.Generator`, :class:`~powersystems.Load`,
+:class:`~powersystems.Bus`, and :class:`~powersystems.Line` objects.
+Also extract the time information and create a :class:`~schedule.Timelist`
+object.
 """
 
 import powersystems
@@ -12,13 +13,14 @@ from commonscripts import readCSV,csvColumn,flatten,unique,drop_case_spaces,join
 
 import os,sys,logging
 
-fields_lines={'name':'name','to':'To','from':'From','pmax':'Pmax'}
+fields_lines={'name':'name','to':'To','from':'From','reactance':'X','pmax':'Pmax'}
 fields_gens={
     'name':'name','type':'kind','kind':'kind','bus':'bus',
-    'pmin':'Pmin','pmax':'Pmax',
+    'pmin':'Pmin','pmax':'Pmax','powermin':'Pmin','powermax':'Pmax',
     'p':'power','pg':'power','power':'power', #for a non-controllable gen in an ED
     'rampratemin':'rampratemin','rampratemax':'rampratemax',
-    'minuptime':'minuptime','mindowntime':'mindowntime',
+    'minuptime':'minuptime','uptimemin':'minuptime',
+    'mindowntime':'mindowntime','downtimemin':'mindowntime',
     'costcurveequation':'costcurvestring', 
     'heatrateequation':'heatratestring','fuelcost':'fuelcost',
     'startupcost':'startupcost','shutdowncost':'shutdowncost',
@@ -52,7 +54,10 @@ def parsedir(datadir='.',
         (not required for ED,OPF problems. Defaults will be used
         for UC problems if not specified.)
     
-    :returns: buses, lines, times (lists of objects)
+    :return generators:, list of :class:`~powersystems.Generator` objects 
+    :return loads:, list of :class:`~Load` objects
+    :return lines:, list of :class:`~powersystems.Line` objects
+    :return times:, list of :class:`~schedule.Timelist` object
     """
     if not os.path.isdir(datadir): raise OSError('data directory "{d}" does not exist'.format(d=datadir) )
     [file_gens,file_loads,file_lines,file_init]=[joindir(datadir,filename) for filename in (file_gens,file_loads,file_lines,file_init)]
@@ -73,13 +78,14 @@ def parsedir(datadir='.',
     try: lines=build_class_list(file_lines,model=powersystems.Line,field_attr_map=fields_lines)
     except IOError: lines=[]
     
-    #create buses list    
-    buses=powersystems.make_buses_list(loads,generators)
-    
-    return buses,lines,times
+    return generators,loads,lines,times
 
 def setup_initialcond(filename,generators,times):
-    '''read initial conditions from spreadsheet and add information to each :class:`powersystems.Generator`.'''
+    '''
+    Read initial conditions from a spreadsheet and
+    add information to each :class:`~powersystems.Generator` 
+    object.
+    '''
     if len(times)<=1: return generators #for UC,ED no need to set initial status
     validFields=fields_initial.keys()
     
@@ -89,7 +95,7 @@ def setup_initialcond(filename,generators,times):
     except IOError: 
         data,fields=[],[]
         logging.warning('No generation initial conditions file found. Setting to defaults.')
-        for gen in generators: gen.setInitialCondition(time=initialTime)
+        for gen in generators: gen.set_initial_condition(time=initialTime)
         return generators
         
     try: attributes=[fields_initial[drop_case_spaces(f)] for f in fields]
@@ -99,7 +105,7 @@ def setup_initialcond(filename,generators,times):
     
     
     #set initial condition for all gens to off
-    for g in generators: g.setInitialCondition(initialTime, u=False, P=0)
+    for g in generators: g.set_initial_condition(initialTime, u=False, P=0)
 
 
     #overwrite initial condition for generators which are specified in the initial file
@@ -113,7 +119,7 @@ def setup_initialcond(filename,generators,times):
             if c in excludeCols: continue
             elif elem is not None: inputs[attributes[c]]=elem
         g=genNames.index(row[nameCol])
-        generators[g].setInitialCondition(time=initialTime,**inputs)
+        generators[g].set_initial_condition(time=initialTime,**inputs)
         
     return generators
 
@@ -168,16 +174,17 @@ def build_class_list(filename,model,field_attr_map,times=None):
     return classL
 
 def setup_times(file_gens,file_loads,datadir):
-    """ Create list of :class:`~schedule.Time` objects 
-        from the schedule files. If there are no schedule
-        files (as in ED,OPF), create just a single
-        :class:`~schedule.Time` instance.
-        
-        :param file_gens:    spreadsheet of generator data
-        :param file_loads:   spreadsheet of load data
-        :param datadir:      directory of data
-        
-        :returns: a :class:`~schedule.Timelist` object
+    """ 
+    Create list of :class:`~schedule.Time` objects 
+    from the schedule files. If there are no schedule
+    files (as in ED,OPF), create just a single
+    :class:`~schedule.Time` instance.
+    
+    :param file_gens:    spreadsheet of generator data
+    :param file_loads:   spreadsheet of load data
+    :param datadir:      directory of data
+    
+    :returns: a :class:`~schedule.Timelist` object
     """
 
 
@@ -213,22 +220,17 @@ def setup_times(file_gens,file_loads,datadir):
     if len(timestrL) == max(n for n in nT_loads+nT_gens): 
         times=schedule.makeTimes(timedateL) #just one schedule
     else: 
-        uniqueTimes=unique(timedateL)
+        uniqueTimes=sorted(unique(timedateL))
         #make times from unique list
         times=schedule.makeTimes(uniqueTimes)
         
     #check for missing data problems by checking length
     nT=len(times)
     if any(n!=nT if n else False for n in nT_loads): 
-        msg='a load has schedule with inconsistent times. load schedule lengths={L} and there are {t} times.'.format(L=nT_loads,t=nT)
+        msg='a load has schedule with inconsistent times. load schedule lengths={L} and there are {t} times.'.format(L=dict(zip(loadScheds,nT_loads)),t=nT)
         raise ValueError(msg)
     if any(n!=nT if n else False for n in nT_gens): 
         msg='a generator has schedule with inconsistent times. gen schedule lengths={L} and there are {t} times.'.format(L=nT_gens,t=nT)
         raise ValueError(msg)
     return times
 
-if __name__ == "__main__": 
-    if len(sys.argv)==1: parsedir()
-    else: 
-        datadir=sys.argv[1]
-        parsedir(datadir=datadir)
