@@ -6,16 +6,17 @@ solvers = Tests()
 
 def simple_problem():
     prob=optimization.newProblem()
-    x= optimization.newVar('x',low=0,high=3)
-    y= optimization.newVar('y',low=0,high=1)
-    prob.addVariables([x,y])
-    prob.addObjective(y-4*x)
-    prob.addConstraints(dict(theconstr=(x+y<=2)))    
+    x= optimization.new_variable('x',low=0,high=3)
+    y= optimization.new_variable('y',low=0,high=1)
+    prob.add_variable(x)
+    prob.add_variable(y)
+    prob.add_objective(y-4*x)
+    prob.add_constraint(optimization.new_constraint('',x+y<=2))
     return prob 
 
 def test_one_solver(solver_name):
     prob=simple_problem()
-    optimization.solve(prob,solver=solver_name)
+    prob.solve(solver=solver_name)
     return prob.status
 
 @solvers.test
